import hookForm from 'hook-easy-form';
import { useDispatch } from 'react-redux';

import { runAuth } from 'store/auth/actions';
import Input from 'components/inputs/text-input/text-input';

import classes from './auth.module.scss';

const form = [
  {
    name: 'email',
    value: '',
    required: true,
    options: {
      type: 'email',
      label: 'Your email'
    }
  },
  {
    name: 'password',
    value: '',
    required: true,
    options: {
      type: 'password',
      label: 'Your password'
    },
    validate: {
      maxLength: (v) => (v.trim().length < 6 ? 'Invalid' : ''),
    },
  },
]

const Auth = () => {
  const dispatch = useDispatch();

  // const [values, setValues] = useState({ email: '', password: '' })
  const { formArray, updateEvent, valid, disabled, submitEvent } = hookForm({ initialForm: form })

  const submit = submitEvent((v) => dispatch(runAuth(v)));

  // console.log('s', formArray);  
  return (
    <form onSubmit={submit} className={classes.container}>
      {formArray.map(el => (
        <div className={classes.form} key={el.name}>
          <Input
            name={el.name}
            label={el.options.label}
            type={el.options.type}
            onChange={updateEvent} />
        </div>
      ))}
      <button type="submit" disabled={disabled || !valid}>Submit</button>
    </form>
  )
}

export default Auth;